@@ -186,17 +186,20 @@ if(Sys.getenv("GPBOOST_ALL_TESTS") == "GPBOOST_ALL_TESTS"){
     y_o <- y + offset
     cov_pars_pred = c(0.5,1.5)
     gp_model_no_offset <- fitGPModel(group_data = group,
-                           y = y,  params = DEFAULT_OPTIM_PARAMS_STD)
+                                     y = y,  params = DEFAULT_OPTIM_PARAMS_STD)
     pred_no_offset <- predict(gp_model_no_offset, group_data_pred = group_test,
-                    cov_pars = cov_pars_pred, predict_cov_mat = TRUE)
+                              cov_pars = cov_pars_pred, predict_cov_mat = TRUE)
     gp_model <- fitGPModel(group_data = group, y = y_o, offset = offset,
                            params = DEFAULT_OPTIM_PARAMS_STD)
-    pred <- predict(gp_model,group_data_pred = group_test, offset = offset,
+    pred <- predict(gp_model, group_data_pred = group_test, offset = offset,
                     cov_pars = cov_pars_pred, predict_cov_mat = TRUE)
+    pred_offset_not_provided <- predict(gp_model, group_data_pred = group_test,
+                                        cov_pars = cov_pars_pred, predict_cov_mat = TRUE)
     expect_lt(sum(abs(as.vector(gp_model$get_cov_pars())-as.vector(gp_model_no_offset$get_cov_pars()))),TOLERANCE_STRICT)
     expect_equal(gp_model$get_num_optim_iter(), gp_model_no_offset$get_num_optim_iter())
     expect_lt(sum(abs(pred$mu-pred_no_offset$mu)),TOLERANCE_STRICT)
     expect_lt(sum(abs(as.vector(pred$cov)-as.vector(pred_no_offset$cov))),TOLERANCE_STRICT)
+    expect_lt(sum(abs(pred$mu-pred_offset_not_provided$mu)),TOLERANCE_STRICT)
     # with lbfgs
     params = DEFAULT_OPTIM_PARAMS_STD
     params$optimizer_cov = "lbfgs"
